pub(crate) struct FontFaceRuleInitiator {
created_by: Arc<LockedFontFaceRule>,
font_face_rule: Descriptors,
callback: StylesheetWebFontLoadFinishedCallback,
}Fields
created_by: Arc<LockedFontFaceRule>A reference to the @font-face rule that created this web font load.
This is only used to identify the font in case it is
font_face_rule: Descriptorscallback: StylesheetWebFontLoadFinishedCallbackTrait Implementations
Sourceimpl MallocSizeOf for FontFaceRuleInitiator
impl MallocSizeOf for FontFaceRuleInitiator
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.