struct KnownFontFaceRules {
generation: bool,
contents: HashMap<Atom, Vec<KnownFontFaceRule>>,
}Fields
generation: boolUsed to distinguish new, incoming @font-face rules from existing ones.
Generations alternate between true and false, which is enough to tell one generation apart from the next.
contents: HashMap<Atom, Vec<KnownFontFaceRule>>Maps from a font family name to a list of @font-face rules declaring fonts
that belong to said family.
Implementations
Sourceimpl KnownFontFaceRules
impl KnownFontFaceRules
Sourcefn diff_old_and_new_font_face_rules(
&mut self,
stylist: &Stylist,
guards: &StylesheetGuards<'_>,
) -> WebFontSetDifference
fn diff_old_and_new_font_face_rules( &mut self, stylist: &Stylist, guards: &StylesheetGuards<'_>, ) -> WebFontSetDifference
Computes the difference between the @font-face rules that are currently in effect
and the ones that the Stylist knows about. The caller is notified about new or removed rules
with callbacks.